@@ -980,6 +980,9 @@ def station_regs(isa_yaml, grp_yaml, attr_yaml, rvxlen, pkg_name,
                     elif 'ro_constant' in type_reg:
                         bsvstr += temp_readOnlyRegister.format(subdescription,
                                 str(width), csrname+'_'+subfield, subreset_val)
+                    elif 'ro_variable' in type_reg:
+                        bsvstr += temp_register.format(subdescription,
+                                str(width), csrname+'_'+subfield, subreset_val)
                     elif 'warl' in type_reg:
                         bsv_str = derive_warl_func( subfield,
                             str(width),subcontent['type']['warl']['legal'],
